<template>
  <ChooseInput :modelValue="inputValue" @click="handleOpen()"></ChooseInput>
</template>

<script setup lang="ts">
import { Portal } from 'senin-mini/components';
import ChooseInput from './ChooseInput.vue';
import { computed, h } from 'vue';
import { Popup, DatePicker, Picker } from '@nutui/nutui-taro';
import CheckboxActionSheet from '../ActionSheet/CheckboxActionSheet.vue';
import _ from 'lodash';

defineOptions({
  name: 'ChooseInputWithCheckbox',
});

type Props = {
  columns: API.GetTypeSearchSettingList[];
  modelValue: Array<string | number>;
  title?: string;
  max?: number;
};

const props = withDefaults(defineProps<Props>(), {});
const inputValue = computed(() =>
  props.modelValue.map((x) => props.columns.find((y) => y.id === x)?.name).join(',')
);

const emit = defineEmits<{
  (e: 'update:modelValue', val: Array<string | number>): void;
}>();

function handleOpen() {
  Portal.add((key) => {
    return h(
      Portal.Container,
      { keyNumber: key, delayOpen: true },
      {
        default: ({ open, onClose }) =>
          h(
            Popup,
            {
              visible: open.value,
              'onUpdate:visible': (value) => !value && onClose(),
              position: 'bottom',
              closeOnClickOverlay: false,
            },
            {
              default: () =>
                h(CheckboxActionSheet, {
                  modelValue: props.modelValue,
                  columns: props.columns,
                  title: props.title,
                  visible: open.value,
                  'onUpdate:visible': (value) => !value && onClose(),
                  'onUpdate:modelValue': (value) => {
                    emit('update:modelValue', value);
                  },
                }),
            }
          ),
      }
    );
  });
}
</script>
